###############################################################################
#	$VER: html-image.wl 2.0 (30.5.1998)
#
#	Copyright  1997,1998 Udo Schuermann
#	All rights reserved.
#
#	This file is part of the WebLord software distribution and is required
#	if you use the old IMAGE object type, which is no longer directly
#	supported as of version 2.0
#
#	WebLord performs an internal conversion of IMAGE objects when these
#	are encountered. The process involves retyping the object as TEXT,
#	adding a VALUE property with a value of "html-image" (i.e. the object
#	defined in this file!), and changing all the object's other property
#	names to begin with "image-" (i.e. "link" becomes "image-link")
#
#	The HTML-IMAGE object defined in this file makes the conversion as
#	smooth and painless as possible, thereby freeing WebLord from the
#	burdens of an implementation that is too closely tied to HTML. I.e.
#	WebLord will be able to easily move into the realm of XML (or apply
#	itself to any other language that you may wish to use.)
#
#	NOTE: Rather than continuing to define IMAGE objects (and suffering
#	the performance penalties of the internal conversion) you should use
#	either TEXT objects directly, or define your images in the following
#	manner:
#
#		text = my-image
#		{
#			value =		html-image;
#			image-src =	"pix/test.gif";
#			image-losrc =	"pix/test-outline.gif";
#			image-width =	"128";
#			image-height =	"72";
#			image-align =	"left";
#			image-border =	"0";
#			image-hspace =	"4";
#			image-vspace =	"1";
#			image-alt =	"A test image";
#			image-title =	"This text shows when it's a link";
#			image-target =	"window-id";
#
#		# either one of the following are acceptable *in this case*
#		# but the first ('link') is preferred:
#			link =		"http://my.site/pix/test-big.gif";
#			image-link =	"http://my.site/pix/test-big.gif";
#		}
#
#	Then merely reference the object the way you would reference
#	an IMAGE object:    "This is a test: " my-image
#	Omit any items you don't need. 'image-src' is the only property that
#	is required.
#
#	Notice that it is easy to adapt the code below for the HTML 4.0 general
#	purpose OBJECT element to handle images, applets, animations, movies,
#	etc. in a more flexible way.
#
###############################################################################
# This is where the good stuff starts. Good study material, too! :-)
# Note that the incessant use of ^ and _ symbols is meant to keep the object
# names "out of your way": they have no special meaning.
#

#requires-version 2.0

text = html-image
{
	if    = isdef image-src;	# did the conversion process produce an 'image-src' property?
	then  = ^html-image-center-start
			^html-image-link-start
				"<img" ^html-image-spec ">"
			^html-image-link-end
		^html-image-center-end;
	else  = html-image-error( text = "Object '" parent.objectname "' defines no 'image-src' property; "
				  "you may need to convert this manually. The object is defined thus:\n"
				  parent.objectdefinition );
}

actor text html-image-error
{
	echo	= error++ text;		# the 'error++' increments the error counter; echo property is echoed to output no
}

text = ^html-image-spec
{
	value = ^html-image-src
		^html-image-losrc
		^html-image-width
		^html-image-height
		^html-image-align
		^html-image-border
		^html-image-hspace
		^html-image-vspace
		^html-image-alt;
}


text = ^html-image-center-start	{ if = image-align "=" "center";	then = "<div align=" HTML-Q( value="center" ) ">" }
text = ^html-image-center-end	{ if = image-align "=" "center";	then = "</div>" }

text = ^html-image-src		{ 					value = " src=" HTML-Q( value = image-src ) }
text = ^html-image-losrc	{ if = isdef image-losrc;		then = " losrc=" HTML-Q( value = image-losrc ) }

text = ^html-image-width 	{ if = isdef image-width;		then = " width=" HTML-Q( value = image-width ) }
text = ^html-image-height	{ if = isdef image-height;		then = " height=" HTML-Q( value = image-height ) }

text = ^html-image-align	{ if = isdef image-align "&" image-align "!=" "center";
				  then = " align=" HTML-Q( value = image-align ) }

text = ^html-image-border	{ if = isdef image-border;		then = " border=" HTML-Q( value = image-border ) }

text = ^html-image-hspace	{ if = isdef image-hspace;		then = " hspace=" HTML-Q( value = image-hspace ) }
text = ^html-image-vspace	{ if = isdef image-vspace;		then = " vspace=" HTML-Q( value = image-vspace ) }

text = ^html-image-alt		{ if = isdef image-alt;			then = " alt=" HTML-Q( value = image-alt ) }

#
# The following is used only an old IMAGE objects that have been converted to TEXT objects internally.
# The conversion process causes "image-" to be prepended to each property, wherefore the internal logic
# will not recognize "image-link" as a standard property; we catch this here:
#
text = ^html-image-link-start	{ if = isdef image-link;	then = "<a" ^_html-link-to ^_html-target-to ^_html-title-to ">" }
text = ^html-image-link-end	{ if = isdef image-link;	then = "</a>" }
text = ^_html-link-to		{ 				value = " href=" HTML-Q( value = image-link ) }
text = ^_html-target-to		{ if = isdef image-target;	then = " target=" HTML-Q( value = image-target ) }
text = ^_html-title-to		{ if = isdef image-title;	then = " title=" HTML-Q( value = image-title ) }
#end-of-file :-)
