############################################################################
#
#	HTML-PAGE-TABULAR-LEFT
#
#	Defines a fairly simple tabular page with a layout like the following:
#
#	 _______________________________________________________________
#	|		|						|
#	| page-logo	|	page-title				|
#	|		|						|
#	|---------------|-----------------------------------------------|
#	|		|						|
#	|		|						|
#	| page-nav	|	page-body				|
#	|		|						|
#	|		|						|
#	|		|						|
#	|		|						|
#	|		|						|
#	|		|						|
#	|		|						|
#	|		|						|
#	|---------------|-----------------------------------------------|
#	| page-footmark	|	page-footer				|
#	|_______________|_______________________________________________|
#
#	Any and all of these may be left undefined. In addition the use of
#	a property 'left-margin' will override a default symbol with a value
#	of '140' -- this allows you to fix the width of the left column
#
#	Example page definition:
#
#	page myPage
#	{
#		value = 	html-page-tabular;
#		left-margin =	'120';
#		page-logo =	'<img src="logo.gif" width="120" height="60">';
#		page-title =	'<h1>Welcome to my Page!</h2>';
#		page-nav =	navigation-bar;
#		page-body =	FILE( filename= 'text/myPage.text' );
#		page-footmark =	'&nbsp;';
#		page-footer =	'<font size="-1">Copyright  1998 by Me</font>';
#	}
#
############################################################################

#requires-version 2.0

text html-page-tabular-left
{
	value =	"<table cellpadding=8 align=left>\n"
		"<tr>" table-Row1-Col1 table-Row1-Col2 "</tr>\n"
		"<tr>" table-Row2-Col1 table-Row2-Col2 "</tr>\n"
		"<tr>" table-Row3-Col1 table-Row3-Col2 "</tr>\n"
		"</table>\n"
}
text table-Row1-Col1 { value =	"<td valign=top width=" left-margin ">"	page-logo	"</td>" }
text table-Row1-Col2 { value =	"<td valign=top>"			page-title	"</td>" }
text table-Row2-Col1 { value =	"<td valign=top width=" left-margin ">"	page-nav	"</td>" }
text table-Row2-Col2 { value =	"<td valign=top>\n"			page-body	"</td>" }
text table-Row3-Col1 { value =	"<td valign=top width=" left-margin ">"	page-footmark	"</td>" }
text table-Row3-Col2 { value =	"<td valign=top>\n"			page-footer	"</td>" }
static text left-margin = "140";	# override this with a page-local property of same name

#end of file
